use chrono::NaiveDateTime;
use serde::{Deserialize, Serialize};
use sqlx::{FromRow, PgPool};
use uuid::Uuid;

#[derive(Clone)]
pub struct MyState {
    pub pool: PgPool,
}

#[derive(Deserialize)]
pub struct TeaMeta {
    pub tea_name: String,
    pub tea_notes: String,
    pub water_temp: i32,
    pub steeping_seconds: i32,
}

#[derive(Deserialize)]
pub struct TeaSteepingTimeChange {
    pub new_steeping_seconds: i32,
}

#[derive(Deserialize)]
pub struct TeaNew {
    pub rfid_code: String,
    pub steeping_seconds: i32,
}

#[derive(Serialize, FromRow)]
pub struct Tea {
    pub id: i32,
    pub tea_name: String,
    pub rfid_code: String,
    pub tea_notes: String,
    pub water_temp: i32,
    pub steeping_seconds: i32,
    pub registration_timestamp: NaiveDateTime,
}

#[derive(Serialize, FromRow)]
pub struct SteepingLog {
    pub change_id: Uuid,
    pub tea_id: i32,
    pub steeping_seconds: i32,
    pub steeping_tested_time: NaiveDateTime,
}

#[derive(Serialize, Deserialize, FromRow)]
pub struct Config {
    pub default_steeping_time: i32,
    pub feedback_timeout: i64,
}
